@@ -166,6 +166,7 @@ class UTextResult(unittest.TextTestResult):
 
         self.testsRun += 1
         item_title = test.shortDescription()  # Better for printing (get from cache).
+
         if item_title == None:
             # For unittest framework where getDescription may return None.
             item_title = self.getDescription(test)
@@ -266,7 +267,11 @@ class UTestCase(unittest.TestCase):
     @classmethod
     def question_title(cls):
         """ Return the question title """
-        return cls.__doc__.strip().splitlines()[0].strip() if cls.__doc__ is not None else cls.__qualname__
+        if cls.__doc__ is not None:
+            title = cls.__doc__.strip().splitlines()[0].strip()
+            if not (title.startswith("Hints:") or title.startswith("Hint:") ):
+                return title
+        return cls.__qualname__
 
     @classmethod
     def reset(cls):
@@ -323,7 +328,7 @@ class UTestCase(unittest.TestCase):
 
     def shortDescriptionStandard(self):
         sd = super().shortDescription()
-        if sd is None:
+        if sd is None or sd.strip().startswith("Hints:") or sd.strip().startswith("Hint:"):
             sd = self._testMethodName
         return sd
 
@@ -495,6 +500,7 @@ class UTestCase(unittest.TestCase):
 
                 er = er[0]
                 doc = er._testMethodDoc
+                # print("doc", doc)
                 if doc is not None:
                     hint = get_hints(er._testMethodDoc)
                     if hint is not None:
